#
# spec file for package libXt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXt
%define lname	libXt6
Version:        1.3.1
Release:        1.1
Summary:        X Toolkit Intrinsics library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXt
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXt/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(kbproto)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.13
BuildRequires:  pkgconfig(xproto)

%description
The low level Xlib library provides functions for interacting with an
X11 server, but does not provide any function for implementing the
graphical objects (widgets) used in GUIs, such as buttons, menus,
etc. The Xt library provides support for creating and using widget
types, but does not provide any specific widget. Specific widgets are
implemented by other libraries using Xt, such as Xaw and Motif.

%package -n %lname
Summary:        X Toolkit Intrinsics library
# O/P added for 12.2
Group:          System/Libraries
Provides:       xorg-x11-libXt = 7.6_%version-%release
Obsoletes:      xorg-x11-libXt < 7.6_%version-%release

%description -n %lname
The low level Xlib library provides functions for interacting with an
X11 server, but does not provide any function for implementing the
graphical objects (widgets) used in GUIs, such as buttons, menus,
etc. The Xt library provides support for creating and using widget
types, but does not provide any specific widget. Specific widgets are
implemented by other libraries using Xt, such as Xaw and Motif.

%package devel
Summary:        Development files for the X Toolkit Intrinsics library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
# O/P added for 12.2
Provides:       xorg-x11-libXt-devel = 7.6_%version-%release
Obsoletes:      xorg-x11-libXt-devel < 7.6_%version-%release

%description devel
The low level Xlib library provides functions for interacting with an
X11 server, but does not provide any function for implementing the
graphical objects (widgets) used in GUIs, such as buttons, menus,
etc. The Xt library provides support for creating and using widget
types, but does not provide any specific widget. Specific widgets are
implemented by other libraries using Xt, such as Xaw and Motif.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
%configure --docdir=%_docdir/%name --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la
%fdupes %buildroot/%_prefix

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libXt.so.6*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXt.so
%_libdir/pkgconfig/xt.pc
%_mandir/man3/*
%_docdir/%name

%changelog
* Tue Nov 19 2024 Stefan Dirsch <sndirsch@suse.com>
- update to 1.3.1
  * README.md: update & correct links to O'Reilly X Toolkit books
  * unifdef ultrix
  * unifdef sgi
  * unifdef hpux
  * unifdef __osf__
  * unifdef AIXV3
  * unifdef MOTOROLA
  * unifdef USG
  * unifdef VMS
  * unifdef __EMX__
  * unifdef AIXSHLIB & SUNSHLIB
  * Improve linking with widget libraries on macOS
  * issue #17: avoid _Static_assert from c++
  * issue #18: cross-build issue in util
  * issue #19: include <process.h> on Windows for getpid()
  * issue #20: c23 boolean conflict
  * remove substitution for EXEEXT_FOR_BUILD, not defined in automake
  * Add continue_to_dispatch parameter to _XtResourceConfigurationEH()
  * eliminate an unnecessary cast
  * quiet a couple of unused-parameter warnings
* Mon Apr 10 2023 Stefan Dirsch <sndirsch@suse.com>
- update to 1.3.0
  * gitlab CI: add a basic build test
  * Fix spelling/wording issues
  * gitlab CI: stop requiring Signed-off-by in commits
  * Use memcpy() instead of memmove() when buffers are known not to overlap
  * Use memcpy() instead of XtMemmove() when buffers are known to differ
  * tests: update g_test_bug_base url from bugzilla to gitlab
  * tests: Use XORG_MEMORY_CHECK_FLAGS from xorg-macros 1.16
  * tests: Replace g_assert() calls with g_assert_*() calls
  * configure.ac: Replace HAVE_LIBRARY with AC_CHECK_LIB
  * Add xfilesearchpath to xt.pc
  * TMstate.c: Handle -Wduplicated-branches warnings
  * Remove "All rights reserved" from Oracle copyright notices
  * configure: Use LT_INIT from libtool 2 instead of deprecated AC_PROG_LIBTOOL
  * test: Add unit tests for XtMalloc, XtCalloc, & XtRealloc
  * Add XtReallocArray() for overflow checking of multiplied args
  * Replace XtRealloc() calls with XtReallocArray()
  * Replace XtMalloc() calls with XtMallocArray()
  * Define LONG64 if __SIZEOF_LONG__ indicates 64-bit long
  * XtArgVal: Support architectures where pointers are bigger than long
  * Use XtUIntPtr for integer types that can hold pointers
  * Cast via intptr_t when converting integers to pointers
  * Fix XrmResource layout if pointers are bigger than long
  * Fix InternalCallbackRec layout if pointers are bigger than 64 bits
  * Support buttons > 5 in translation tables [v2]
  * add _X_NORETURN to agree with header-file
  * codespell-fixes
  * cppcheck and clang --analyze fixes
  * fixes for gcc13 warnings
  * cppcheck fixes (const, null dereferencing, uninitialized, scope)
  * cppcheck (revise IsDescendant() to fix possible null-dereference)
  * update copyright-date
* Sun Jan 24 2021 Dirk Müller <dmueller@suse.com>
- update to 1.2.1:
  * _XtCalloc actually uses a Cardinal, not size_t
  * add errorhandling to _XtVaToTypedArgList()
  * refactoring, reduce indent level
  * work within existing interface which attempts to obtain the
    display-pointer from the screen-pointer but fails when the screen-pointer
    itself is invalid.  Ensure that the screen-pointer is valid by checking
    the default_screen value against the valid range, and forcing it to zero
    if it is out of bounds.
  * indent
* Wed Jul  3 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.0
  * bug fixes
- supersedes U_libXt_code-cleanup.patch
* Wed Nov 22 2017 zaitor@opensuse.org
- Add U_libXt_code-cleanup.patch: Get rid of some extraneous ; at
  the end of C source lines.
- Drop unneeded autoconf, automake and libtool BuildRequires.
* Mon May  4 2015 sndirsch@suse.com
- Update to version 1.1.5
  * Revert "Avoid shadowing variables."
  * If CFLAGS_FOR_BUILD is not set, include CWARNFLAGS in default value
  * makestrs: use strchr() instead of index()
  * makestrs: Replace malloc()+strcpy() calls with strdup() calls
  * makestrs: Replace strcpy()+strcat() calls with snprintf() calls
  * makestrs: Use asprintf() if available
  * unifdef -UCRAY -UCRAY2
  * Use $(MKDIR_P) in Makefile.am for better code portability
  * Include direct.h header for _getdrives() on Win32
  * Include unistd.h for getpid()
  * asprintf needs _GNU_SOURCE on some platforms
  * Fix cross-compilation
  * Add missing comma to fix DEBUG build.
  * Use appropriate variable type for vsnprintf return value.
  * Mark non-returning function with appropriate attribute.
  * Ignore test-driver from automake-1.13.
  * Avoid shadowing variables.
  * Fix char vs. unsigned char warnings.
  * Use string.h instead of X11/Xos.h.
  * Fix _XtInherit on x86_64 Windows
* Sat Jun  1 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.1.4:
  This release provides the fixes for the recently announced security issues
  CVE-2013-2002 & CVE-2013-2005, along with other code & doc cleanups, build
  fixes, automake compatibility changes, and packaging improvements.
- Packaging changes:
  + Removed Patch1 - libXt.diff - part upstreamed, part not applicable
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
- Avoid calling fdupes outside of /usr
* Thu Apr 12 2012 vuntz@opensuse.org
- Update to version 1.1.3:
  + Revert "Treat unexpected returned events from poll as errors":
    this caused regressions.
- Changes from version 1.1.2:
  + Good number of bug fixes:
  - Make XtAppMainLoop work without a Display
  - LP64 fix for TypedArgToArg()
  - add missing bound checking in FreeSelectionProperty()
  - don't pop elements from array while iterating through it
  - don't re-enter the WaitLoop if block is set to false
  - treat unexpected returned events from poll as errors
  + Initial unit tests for checking several recent fixes
  + Fixes for compiler warnings
  + Documentation for the libXt API moved to the DocBook/XML format
  + Build configuration improvements
- Changes from version 1.1.1:
  + Fix longstanding crash on 64bit sparc
  + Fix memory corruption in XtAsprintf
  + Build fixes
- Changes from version 1.1.0:
  + Add XtAsprintf to exported API
  + Bug fixes:
  - various fixes related to NULL access/reference
  - protect against underflow when type conversion fails in
    GetResources
  - fix iconic state being ignored in initial state
  + Janitorial cleanups
  + Build configuration improvements
- Pass --docdir=%%_docdir/%%name to configure to correctly install
  the libXt API documentation.
- Update libXt.diff to use $(datadir) instead of /usr/share so that
  it's upstreamable.
* Sun Feb 12 2012 jengelh@medozas.de
- Rename xorg-x11-libXt to libXt and utilize shlib policy
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Oct  5 2011 uli@suse.com
- cross-build fixes: use %%__cc macro, export CFLAGS correctly
* Fri Jun 17 2011 pgajdos@novell.com
- escape %%S in --with-xfile-search-path [bnc#697135]
* Tue May 24 2011 giecrilj@stegny.2a.pl
- Add README
* Thu May 19 2011 eich@suse.de
- Remove patch app-defaults.diff
  Use the configure option --with-xfile-search-path to specify
  the search path in the spec file.
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6_1.0.9
* Wed Dec  1 2010 jslaby@suse.de
- revert 'export only public API symbols'
  it breaks xterm, xclock and others
* Tue Nov 30 2010 cristian.rodriguez@opensuse.org
- export only public API symbols
- disable silent rules, defeat the purpose of post build checks
* Fri Oct 29 2010 sndirsch@novell.com
- libXt 1.0.9
  * This release includes several bug fixes, as well as the usual
    set of recent build configuration improvements & janitorial
    cleanups.
* Sat Sep  4 2010 sndirsch@suse.de
- libXt 1.0.8
- bumped version number to 7.5_1.0.8
- make use of %%fdupes macro
- fixed Summary/Group entries in -devel package
* Sun Apr  4 2010 sndirsch@suse.de
- libXt 1.0.7
- adjusted libXt.diff
- bumped version number to 7.5
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sat Nov 14 2009 sndirsch@suse.de
- regenerated libXt.diff
- fixed build
* Sat Jul  4 2009 sndirsch@suse.de
- libXt 1.0.6
  * bugfix release
* Fri May  1 2009 eich@suse.de
- revert static library and .la file removal
  for SUSE versions <= 11.1.
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- run ldconfig in postun
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Mon Jan 29 2007 sndirsch@suse.de
- update release to 1.0.5
  * Bug 9514: Markup error in makestrs.1x man page
* Wed Nov  8 2006 sndirsch@suse.de
- update release to 1.0.4 (X.Org 7.2 RC2)
  * Add more generated files to ignore.
  * Fix .pc file with new autotools by using AC_DEFINE_DIR.
* Sat Oct 14 2006 sndirsch@suse.de
- updated to X.Org 7.2RC1
* Wed Aug  2 2006 sndirsch@suse.de
- completed search path for old app-defaults location
* Wed Aug  2 2006 sndirsch@suse.de
- fix setup line
* Mon Jul 31 2006 sndirsch@suse.de
- use /usr/share/X11 as default path for XtErrorDB, since this is
  also the new default path for XErrorDB
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
- remove existing /usr/include/X11 symlink in %%pre
* Tue Jul 25 2006 sndirsch@suse.de
- added app-defaults dir to package
* Tue Jul 25 2006 sndirsch@suse.de
- app-defaults.diff: read also /usr/X11R6/lib/X11/app-defaults
* Thu Jun 22 2006 sndirsch@suse.de
- created package
